@@ -236,10 +236,13 @@
     Updated by      Richard Gooch   1-JAN-2002: Changed to extended regular
   expressions.
 
-    Last updated by Richard Gooch   14-JAN-2002: Fixed dummy opens of
+    Updated by      Richard Gooch   14-JAN-2002: Fixed dummy opens of
   /dev/null so that fds [0:2] are open (was only doing fds [0:1]) and prevent
   infinite loop if /dev/null cannot be opened.
 
+    Last updated by Richard Gooch   20-JAN-2002: Fixed <action_compat> to
+  ignore new compatibility names for IDE devices.
+
 
 */
 #define _GNU_SOURCE
@@ -1475,7 +1478,7 @@ static void action_compat (const struct devfsd_notify_struct *info,
 			  host, bus, target, lun, atoi (ptr + 4) );
 	    else compat_name = NULL;
 	}
-	else if (strncmp (info->devname, "ide/", 4) == 0)
+	else if (strncmp (info->devname, "ide/host", 8) == 0)
 	{
 	    int host, bus, target, lun;
 
